/**************************************************************************
*                                                                         *
*                          HELPER FUNCTIONS                               *
*                                                                         *
**************************************************************************/
/*
add_element: appends a new html element matching the string passed as the argument
element to the html element where. The new element has its attributes set according
to the passed data via the set_attributes function below
*/
function add_element(data, element, where) {
  var new_element = document.createElement(element)
  new_element = set_attributes(new_element, data)
  where.appendChild(new_element)
}

/*
set_attributes: sets the attributes of the passed element accroding to the data

element: an html element either from selection e.g. document.getElementById(id)
         or freshly created e.g. document.createElement("section")

data:    an object where keys are valid attributes of the html tag of the passed
         element, e.g. for <link> type and href, for <script>, src.
         The passed element's attributes are set to the data's corresponding values

attribtues_to_ignore: a list of keys in the passed data object of attributes to
ignore. e.g. if you do not wish to set the href for an <a> but wish to set
the innerHTML, you can pass ["href"]

*/
function set_attributes(element, data, attributes_to_ignore) {
  if (attributes_to_ignore == undefined) {
    attributes_to_ignore = []
  }


  var data_attributes = keys(data)
  for (var i = 0; i < data_attributes.length; i++) {
    var current_attribute = data_attributes[i]
    if (current_attribute == "onclick") {
      element.onclick = function(){eval(data[current_attribute])}
      continue
    }

    if (attributes_to_ignore.indexOf(current_attribute) == -1) {
      if (data[current_attribute] == "true" || data[current_attribute] == 'false') {
        element[current_attribute] = eval(data[current_attribute])
      } else {
        element[current_attribute] = data[current_attribute]
        
      }
    }
  }
  return element
}

// Load json function using ajax either syncronously or asychronously
// Requires that jQuery is sourced prior to sourcing this script
function ajax_json(file, sync) {
  if (sync == undefined) {
    sync = true
  }
  var data = $.ajax({
    url: file,
    async: !sync,
    dataType: 'json',
    success: function (data) {
      return data
    },
    error: function() {
      console.log("File " + file + " failed to load.")
    }
  });
  return data.responseJSON
}

// Convenient shorthand
function keys(data) {
  return Object.keys(data)
}

function values(data) {
  var values = keys(data).map(function(key) {return data[key];});
  return values
}

function htmlCollectionToArray(collection) {
  var arr = [].slice.call(collection);
  return arr
}




// Give JS arrays the .last() function prototype
if (!Array.prototype.last){
    Array.prototype.last = function(){
        return this[this.length - 1];
    };
};

if (!Array.prototype.empty){
    Array.prototype.empty = function(){
        return this.length == 0;
    };
};




// Access a nested value of an object using a string
// e.g.
// var a = {"b": {"c": 3}}
// flat_access(a, "b.c") returns 3
function flat_access(object, string) {
  // convert indexes to properties
  string = string.replace(/\[(\w+)\]/g, '.$1');
  // strip a leading dot
  string = string.replace(/^\./, '');
  // list of keys, reversed
  var access = string.split('.').reverse()
  while (!access.empty()) {
    var current_key = access.pop()
    if (current_key in object) {
        object = object[current_key]
    } else {
        return
    }
  }
  return object
}
