function make_oob_plot(models) {
  var svg, chart_group, data_extent, canvas, margins, max_draw_space, doc_state
  var plot = "out_of_bag_error"
  // extract current model
  var model = extractModel(models)
  // extract corresponding data
  var data = model[plot]
  // Make SVG element and group for the chart
  var output_container_id = charts_config.chart_container

  svg = make_chart_svg(plot)
  if (svg.select("g.plot_group").empty()) {
    chart_group = svg.append("g").attr("class", "plot_group")
    charts_config.document_state.current_plot = plot
  } else {
    chart_group = svg.select("g.plot_group")
  }

  var data_extent, x_axis_label, y_axis_label
  data_extent = {
    "max": {
      "x": d3.max(data, function(d) {return d.trees}),
      "y": d3.max(data, function(d) {return Math.max(d.conditions.treatment, d.conditions.control, d.conditions.both)})
    },
    "min": {
      "x": d3.min(data, function(d) {return d.trees}),
      "y": d3.min(data, function(d) {return Math.min(d.conditions.treatment, d.conditions.control, d.conditions.both)})
    }
  }

  x_axis_label = "Trees"
  y_axis_label = "Error"

  canvas = extract_canvas_from_svg(svg)
  margins = make_margins(chart_group, canvas, data_extent, true)
  max_draw_space = calculate_maximum_drawing_space(canvas, margins)
  make_title(chart_group, ["OOB error rate vs number of trees"], margins, canvas, max_draw_space)
  var x_scale = d3.scaleLinear().domain([data_extent.min.x, data_extent.max.x]).range([0, max_draw_space.x])
  var y_scale = d3.scaleLinear().domain([data_extent.max.y, data_extent.min.y]).range([0, max_draw_space.y])
  make_axes(chart_group, x_scale, y_scale, canvas, margins, max_draw_space, x_axis_label, y_axis_label)


  var lineKeys = d3.keys(data[0].conditions)
  // If first call, add the line
  if (chart_group.selectAll("g." + plot + "_line_group").empty()) {
    // Add the group for the line
    chart_group.append("g").attr("class", plot + "_line_group")
    chart_group.select("g." + plot + "_line_group").selectAll("g.line")
              .data(lineKeys)
              .enter()
              .append("g")
              .attr("class", "line")
              .append("path")
              .attr("class", function(d) {return "line_" + d})

    chart_group.append("g").attr("class", plot + "_point_group")
    chart_group.select("g." + plot + "_point_group").selectAll("g.points")
              .data(lineKeys)
              .enter()
              .append("g")
              .attr("class", "hidden_points")
              .selectAll("circle")
              .data(function(d, i) {
                return Object.values(data).map(
                  function(dat, ind) {
                    return {"x": dat.trees, "y": dat.conditions[d], "condition": d}
                  })
                })
              .enter()
              .append("circle")
              .attr("class", function(d) {
                return "circle_" + d.condition
              })


  }

  // Double mapped function, first to groups contain each a path svg element
  // and then mapped amongst those paths to construct the lines.
  chart_group.select("g." + plot + "_line_group").selectAll("g.line")
            .each(function(d,i){
              var currentLineGroup = d3.select(this).select("path").data([data])
              var curCond = d
              var curLine = i
              var line = d3.line()
                           .x(function (d) {return x_scale(d.trees) + margins.x.left + margins.axes.y})
                           .y(function (d) {return y_scale(d.conditions[curCond])+ margins.y.top + margins.title + margins.buttons})
              currentLineGroup.attr("d", line)
                              .attr("fill", "none")
                              .attr("stroke", function(d,i) {return charts_config.colors.palette[curLine * 3]})
                              .attr("stroke-width", charts_config.plots.line.width)

            })

  // Double mapped function, first to groups contain each a set of points (circle svg elements)
  // and then mapped amongst those circles.
  chart_group.select("g." + plot + "_point_group").selectAll("g.hidden_points")
            .each(function (d,i) {
              var currentCircleGroup = d3.select(this).selectAll("circle")
              currentCircleGroup.attr("r", charts_config.plots.line["hidden_radius"])
              .attr("fill", function() {return charts_config.colors.palette[i * 3]})
              .style("opacity", 0)
              .attr("transform", function(d, i) {return "translate(" + (x_scale(d.x) + margins.x.left + margins.axes.y) + "," + (y_scale(d.y)+ margins.y.top + margins.title + margins.buttons) + ")"})
              .on("mouseover", mouseoverFunction)
              .on("mouseout", mouseoutFunction)
            })


  function mouseoverFunction(d, i) {
      d3.select(this).style("opacity", charts_config.plots.line.opacity.hover)
      x = x_scale(d.x) + margins.x.left + margins.axes.y
      y = y_scale(d.y) + margins.y.top + margins.title + margins.buttons
      make_tooltip(d3.select(this), [d.x,  d.condition + ": "+ d.y], chart_group, canvas, margins)
  }
  function mouseoutFunction(d, i) {
      chart_group.select("g.tooltip_group").remove()
      d3.select(this).style("opacity", 0)
  }

}
