function make_pca_plot(models) {
  var svg, chart_group, data_extent, canvas, margins, max_draw_space, doc_state
  var plot = "principal_component_analysis"
  // extract current model
  var model = extractModel(models)
  // extract corresponding data
  var data = model[plot].samples

  var output_container_id = charts_config.chart_container

  svg = make_chart_svg(plot)
  if (svg.select("g.plot_group").empty()) {
    chart_group = svg.append("g").attr("class", "plot_group")
    charts_config.document_state.current_plot = plot
  } else {
    chart_group = svg.select("g.plot_group")
  }

  var data_extent, x_axis_label, y_axis_label
  data_extent = {
    "max": {
      "x": d3.max(data, function(d) {return d.distance.x}),
      "y": d3.max(data, function(d) {return d.distance.y})
    },
    "min": {
      "x": d3.min(data, function(d) {return d.distance.x}),
      "y": d3.min(data, function(d) {return d.distance.y})
    }
  }

  x_axis_label = "PC 1: " + model[plot]["component_variance"]["prinicpal_component_1"] + "%"
  y_axis_label = "PC 2: " + model[plot]["component_variance"]["prinicpal_component_2"] + "%"
  canvas = extract_canvas_from_svg(svg)
  margins = make_margins(chart_group, canvas, data_extent, true)
  max_draw_space = calculate_maximum_drawing_space(canvas, margins)
  make_title(chart_group, ["PCA Plot"], margins, canvas, max_draw_space)
  var x_scale = d3.scaleLinear().domain([data_extent.min.x, data_extent.max.x]).range([0, max_draw_space.x])
  var y_scale = d3.scaleLinear().domain([data_extent.max.y, data_extent.min.y]).range([0, max_draw_space.y])
  make_axes(chart_group, x_scale, y_scale, canvas, margins, max_draw_space, x_axis_label, y_axis_label)

  var previous_points = chart_group.selectAll("g." + plot + "_scatter_group").size()
  var current_points = data.length
  var scatter_group = chart_group.selectAll("g." + plot + "_scatter_group").data(data)


  var groups = extract_all_groups(data, "group")

  if (previous_points < current_points) {
    // Add the points
    chart_group.selectAll("g." + plot + "_scatter_group")
              .data(data)
              .enter()
              .append("g")
              .attr("class", plot + "_scatter_group")
              .append("circle")
              .attr("r", charts_config.plots.scatter.point.radius)
              .attr("fill", function(d, i) {return charts_config.colors.palette[groups.indexOf(d.group) * 5]})
              .style("opacity", charts_config.plots.scatter.opacity.non_hover)
  } else if (previous_points > current_points) {
    scatter_group.exit().transition().delay(function(d, i) {return 100 + i * 10})
    .attr("transform", "translate(0,0)")
  } else {

  }

  scatter_group = d3.selectAll("g." + plot + "_scatter_group")
  scatter_group.transition().delay(function(d, i) {return 100 + i * 10})
               .attr("transform", function(d, i) {return "translate(" + (x_scale(d.distance.x) + margins.x.left + margins.axes.y) + "," + (y_scale(d.distance.y)+ margins.y.top + margins.title + margins.buttons) + ")"})


               scatter_group.on("mouseover", mouseoverFunction)
               scatter_group.on("mouseout", mouseoutFunction)

 function mouseoverFunction(d, i) {
  var d = d3.select(this).datum()
  make_tooltip(d3.select(this), ["Sample: " + d.sample, "Group: " + d.group], chart_group, canvas, margins)
 }

 function mouseoutFunction(d, i) {
  chart_group.select("g.tooltip_group").remove()
 }

}
