function make_roc_plot(models) {
  var svg, chart_group, data_extent, canvas, margins, max_draw_space, doc_state
  var plot = "receiver_operating_characteristic"
  // extract current model
  var model = extractModel(models)
  // extract corresponding data
  var data = model[plot]["true_positive_rate"]

  var output_container_id = charts_config.chart_container
  svg = make_chart_svg(plot)
  if (svg.select("g.plot_group").empty()) {
    chart_group = svg.append("g").attr("class", "plot_group")
    charts_config.document_state.current_plot = plot
  } else {
    chart_group = svg.select("g.plot_group")
  }

  var data_extent, x_axis_label, y_axis_label
  data_extent = {
    "max": {
      "x": d3.max(data, function(d) {return d.x}),
      "y": d3.max(data, function(d) {return d.y})
    },
    "min": {
      "x": d3.min(data, function(d) {return d.x}),
      "y": d3.min(data, function(d) {return d.y})
    }
  }

  x_axis_label = "False positive rate"
  y_axis_label = "True positive rate"
  canvas = extract_canvas_from_svg(svg)
  margins = make_margins(chart_group, canvas, data_extent, true)
  max_draw_space = calculate_maximum_drawing_space(canvas, margins)
  make_title(chart_group, ["ROC Plot"], margins, canvas, max_draw_space)
  var x_scale = d3.scaleLinear().domain([data_extent.min.x, data_extent.max.x]).range([0, max_draw_space.x])
  var y_scale = d3.scaleLinear().domain([data_extent.max.y, data_extent.min.y]).range([0, max_draw_space.y])
  make_axes(chart_group, x_scale, y_scale, canvas, margins, max_draw_space, x_axis_label, y_axis_label)

  var line = d3.line().x(function (d) {return x_scale(d.x) + margins.x.left + margins.axes.y}).y(function (d) {return y_scale(d.y)+ margins.y.top + margins.title + margins.buttons})
  if (chart_group.selectAll("g." + plot + "_line_group").empty()) {
    // Add the group for the line
    chart_group.append("g").attr("class", plot + "_line_group").append("path")

    chart_group.selectAll("g." + plot + "_point_group")
              .data(data)
              .enter()
              .append("g")
              .attr("class", plot + "_point_group")
              .append("circle")
              .attr("r", charts_config.plots.line.hidden_radius)
              .style("opacity", 0)

  }

  var line_group = d3.selectAll("g." + plot + "_line_group").data(data)
  line_group.select("path")
            .data([data])
            .attr("class", "line")
            .attr("d", line)
            .attr("fill", charts_config.plots.line.fill)
            .attr("stroke", charts_config.plots.line.stroke)
            .attr("stroke-width", charts_config.plots.line.width)

  var point_group = d3.selectAll("g." + plot + "_point_group").data(data)
  point_group.attr("transform", function(d, i) {return "translate(" + (x_scale(d.x) + margins.x.left + margins.axes.y) + "," + (y_scale(d.y)+ margins.y.top + margins.title + margins.buttons) + ")"})

  point_group.on("mouseover", mouseoverFunction)
  point_group.on("mouseout", mouseoutFunction)

 function mouseoverFunction(d, i) {
   d3.select(this).select("circle").style("opacity", charts_config.plots.line.opacity.hover).style("fill", charts_config.plots.line.stroke)
   x = x_scale(d.x) + margins.x.left + margins.axes.y
   y = y_scale(d.y) + margins.y.top + margins.title + margins.buttons
   make_tooltip(d3.select(this), [d.x, "TPR: "+ d.y], chart_group, canvas, margins)
 }

 function mouseoutFunction(d, i) {
  chart_group.select("g.tooltip_group").remove()
  d3.select(this).select("circle").style("opacity", 0)
 }

}
